@@ -26,7 +26,8 @@ from . enc import encrypt
 from . formsets import build_formset
 from . widgets import *
 from . settings import *
-from . utils import (_split_choices,
+from . utils import (format_field_name,
+                     _split_choices,
                      _split_choices_in_list_canc,
                      _successivo_ad_oggi)
 
@@ -72,15 +73,6 @@ def get_fields_types(class_name=sys.modules[__name__]):
     return fields_types
 
 
-def format_field_name(field_name, lower=True):
-    f = field_name.replace(' ','_')
-    f = f.replace('(','')
-    f = f.replace(')','')
-    f = f.replace('/','_')
-    if lower: return f.lower()
-    return f.upper
-
-
 class BaseCustomField(Field):
     """
     Base Class that defines methods for every field
@@ -695,6 +687,8 @@ class CustomComplexTableField(ChoiceField, BaseCustomField):
     def clean(self, *args, **kwargs):
         # If is_required and there aren't forms raise ValidationError.
         # Else, each form will clean itself, raising its own fields errors.
+        if not self.widget.formset:
+            raise ValidationError(self.validation_error)
         if self.required and not self.widget.formset.forms:
             raise ValidationError(self.validation_error)
         return
